md_dedupe_headings

Function md_dedupe_headings 

pub fn md_dedupe_headings(
    path: &Path,
    mode: ApplyMode,
    guard: Option<&PathGuard>,
) -> Result<(EditResult, Vec<String>)>
Remove duplicate headings at the same level in a markdown file.

Returns the EditResult and a list of removed duplicate heading texts. Retains direct implementation because the removed-headings list is not available from the tx engine output.