BatchArgs

Struct BatchArgs 

pub struct BatchArgs {
    pub input: String,
    pub write: WriteFlags,
}
Execute multiple operations from a simple line-oriented format.

Each line is one operation with positional arguments:

doc.set <path> <selector> <value>
doc.delete <path> <selector>
doc.merge <path> <json-value>
doc.ensure <path> <selector> <value>
doc.append <path> <selector> <value>
doc.prepend <path> <selector> <value>
doc.update <path> <selector> <value>
doc.move <path> <from> <to>
doc.delete_where <path> <selector> <predicate>
replace <path> <from> <to>
file.create <path> <content>
file.delete <path>
file.rename <from> <to>
md.upsert_bullet <path> <heading> <bullet>
md.table_append <path> <heading> <row>
md.replace_section <path> <heading> <content>
md.insert_after_heading <path> <heading> <content>
md.insert_before_heading <path> <heading> <content>
md.dedupe_headings <path>
md.lint_agents <path>
tidy.fix <path>

Lines starting with # are comments. Empty lines are ignored. Values containing spaces must be quoted with double quotes.

Fields

input: String

Read operations from a file, or stdin if omitted.

write: WriteFlags