pub enum Matcher {
Regex(Regex),
Literal(Box<Finder<'static>>),
}Expand description
Matcher abstraction: either a compiled regex or a memchr literal finder.
Variants
Implementations
Sourceimpl Matcher
impl Matcher
Sourcepub fn find(&self, text: &str) -> Option<(usize, usize)>
pub fn find(&self, text: &str) -> Option<(usize, usize)>
Find the first match in text, returning (start, end) byte offsets.
Sourcepub fn find_iter_positions(&self, text: &str) -> Vec<(usize, usize)>
pub fn find_iter_positions(&self, text: &str) -> Vec<(usize, usize)>
Iterate all matches in text (for multiline mode).
Sourcepub fn count_matches(&self, text: &str, stop_after_first: bool) -> usize
pub fn count_matches(&self, text: &str, stop_after_first: bool) -> usize
Count matches in text, optionally stopping after the first match.