pub struct WritePolicyOverride {
pub ensure_final_newline: Option<bool>,
pub normalize_eol: Option<String>,
pub trim_trailing_whitespace: Option<bool>,
pub collapse_blanks: Option<bool>,
pub respect_editorconfig: Option<bool>,
}Expand description
Partially-specified write policy for config files, plans, and overrides.
Each field is optional; only Some values override the base WritePolicy.
Used by .patchloom.toml config, tx plan write_policy, and any context
that needs to partially override write transformations.
Fields
ensure_final_newline: Option<bool>normalize_eol: Option<String>trim_trailing_whitespace: Option<bool>collapse_blanks: Option<bool>respect_editorconfig: Option<bool>Trait Implementations
Sourceimpl Clone for WritePolicyOverride
impl Clone for WritePolicyOverride
Sourcefn clone(&self) -> WritePolicyOverride
fn clone(&self) -> WritePolicyOverride
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WritePolicyOverride
impl Debug for WritePolicyOverride
Sourceimpl Default for WritePolicyOverride
impl Default for WritePolicyOverride
Sourcefn default() -> WritePolicyOverride
fn default() -> WritePolicyOverride
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for WritePolicyOverridewhere
WritePolicyOverride: Default,
impl<'de> Deserialize<'de> for WritePolicyOverridewhere
WritePolicyOverride: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<WritePolicyConfig> for WritePolicyOverride
impl From<WritePolicyConfig> for WritePolicyOverride
Sourcefn from(c: WritePolicyConfig) -> Self
fn from(c: WritePolicyConfig) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for WritePolicyOverride
impl JsonSchema for WritePolicyOverride
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WritePolicyOverride
impl RefUnwindSafe for WritePolicyOverride
impl Send for WritePolicyOverride
impl Sync for WritePolicyOverride
impl Unpin for WritePolicyOverride
impl UnsafeUnpin for WritePolicyOverride
impl UnwindSafe for WritePolicyOverride