pub struct BatchArgs {
pub input: String,
pub write: WriteFlags,
}Expand description
Execute multiple operations from a simple line-oriented format.
Each line is one operation with positional arguments:
doc.set <path> <selector> <value>
doc.delete <path> <selector>
doc.merge <path> <json-value>
doc.ensure <path> <selector> <value>
doc.append <path> <selector> <value>
doc.prepend <path> <selector> <value>
doc.update <path> <selector> <value>
doc.move <path> <from> <to>
doc.delete_where <path> <selector> <predicate>
replace <path> <from> <to>
file.create <path> <content>
file.delete <path>
file.rename <from> <to>
md.upsert_bullet <path> <heading> <bullet>
md.table_append <path> <heading> <row>
md.replace_section <path> <heading> <content>
md.insert_after_heading <path> <heading> <content>
md.insert_before_heading <path> <heading> <content>
md.dedupe_headings <path>
md.lint_agents <path>
tidy.fix <path>Lines starting with # are comments. Empty lines are ignored.
Values containing spaces must be quoted with double quotes.
Fields
input: StringRead operations from a file, or stdin if omitted.
write: WriteFlagsTrait Implementations
Sourceimpl Args for BatchArgs
impl Args for BatchArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for BatchArgs
impl FromArgMatches for BatchArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Auto Trait Implementations
impl Freeze for BatchArgs
impl RefUnwindSafe for BatchArgs
impl Send for BatchArgs
impl Sync for BatchArgs
impl Unpin for BatchArgs
impl UnsafeUnpin for BatchArgs
impl UnwindSafe for BatchArgs