Module plan

Module plan 

Transaction plan format parsing.

Structs

FormatStep
A format step to run after applying operations but before validation.
Plan
A transaction plan containing multiple operations to execute atomically.
PlanWritePolicy
Write policy settings specified in the plan.
ValidationStep
A validation step to run after applying operations.

Enums

Operation
A single operation within a plan.

Constants

SCHEMA_VERSION
Current plan schema version.

Functions

parse_plan
Parse a plan from a JSON string.
parse_plan_auto
Detect plan format from a file path extension and parse accordingly.
parse_plan_toml
Parse a plan from a TOML string.
parse_plan_yaml
Parse a plan from a YAML string.