Transaction plan format parsing.
Structs
- Format
Step - A format step to run after applying operations but before validation.
- Plan
- A transaction plan containing multiple operations to execute atomically.
- Plan
Write Policy - Write policy settings specified in the plan.
- Validation
Step - A validation step to run after applying operations.
Enums
- Operation
- A single operation within a plan.
Constants
- SCHEMA_
VERSION - Current plan schema version.
Functions
- parse_
plan - Parse a plan from a JSON string.
- parse_
plan_ auto - Detect plan format from a file path extension and parse accordingly.
- parse_
plan_ toml - Parse a plan from a TOML string.
- parse_
plan_ yaml - Parse a plan from a YAML string.